@@ -50,20 +50,20 @@ def create_config(
         ...,
         help="Single or multiple alignment-files (or a directory containing them).",
     ),
-    names: Path = typer.Option(
-        ...,
+    names: Optional[Path] = typer.Option(
+        None,
         exists=True,
         file_okay=True,
         help="Path to the (NCBI) names.dmp.gz.",
     ),
-    nodes: Path = typer.Option(
-        ...,
+    nodes: Optional[Path] = typer.Option(
+        None,
         exists=True,
         file_okay=True,
         help="Path to the (NCBI) nodes.dmp.gz.",
     ),
-    acc2tax: Path = typer.Option(
-        ...,
+    acc2tax: Optional[Path] = typer.Option(
+        None,
         exists=True,
         file_okay=True,
         help="Path to the (NCBI) acc2tax.gz.",
@@ -157,12 +157,21 @@ def create_config(
         "--long-name",
         help="Use the full name of the sample file as sample name..",
     ),
+    damage_mode: cli_utils.DAMAGE_MODE = typer.Option(
+        cli_utils.DAMAGE_MODE.LCA,
+        case_sensitive=False,
+        help="The Damage Mode. Use 'LCA' unless you know what you are doing.",
+    ),
 ):
     """Generate the config file."""
 
     import yaml
     from metaDMG import utils
 
+    if damage_mode.lower() == "lca" & any(x is None for x in [names, nodes, acc2tax]):
+        typer.echo("--names, --nodes, and --acc2tax are mandatory when doing LCA.")
+        raise typer.Exit(code=1)
+
     config = utils.remove_paths(
         {
             "samples": utils.extract_alignments(
@@ -193,6 +202,7 @@ def create_config(
             "cores_pr_fit": cores_pr_fit,
             "bayesian": bayesian,
             "config_path": str(config_path),
+            "damage_mode": damage_mode.lower(),
         }
     )
 
