@@ -1,3 +1,5 @@
+#%%
+
 import pandas as pd
 from pathlib import Path
 import subprocess
@@ -45,13 +47,13 @@ def data_dir(config, name, suffix="parquet"):
 
 
 def get_LCA_command(config):
-    sample = config["sample"]
+    outnames = config["path_tmp"] / config["sample"]
     lca_rank = f"-lca_rank {config['lca_rank']}" if config["lca_rank"] != "" else ""
 
     command = (
         f"{config['metaDMG-lca']} lca "
         f"-bam {config['bam']} "
-        f"-outnames {sample} "
+        f"-outnames {outnames} "
         f"-names {config['names']} "
         f"-nodes {config['nodes']} "
         f"-acc2tax {config['acc2tax']} "
@@ -64,14 +66,15 @@ def get_LCA_command(config):
         f"-howmany {config['max_position']} "
         f"-weighttype {config['weighttype']} "
         f"-fix_ncbi {config['fix_ncbi']} "
+        f"-tempfolder {config['path_tmp']}/ "
     )
     return command[:-1]
 
 
 def get_LCA_mismatches_command(config):
     sample = config["sample"]
-    bdamage = f"{sample}.bdamage.gz"
-    lca_stat = f"{sample}.lca.stat"
+    bdamage = config["path_tmp"] / f"{sample}.bdamage.gz"
+    lca_stat = config["path_tmp"] / f"{sample}.stat"
 
     command = (
         f"{config['metaDMG-lca']} print_ugly "
@@ -86,15 +89,64 @@ def get_LCA_mismatches_command(config):
 #%%
 
 
+def get_runmode(config):
+
+    runmode = config["damage_mode"]
+
+    if runmode == "lca":
+        raise AssertionError(f"mixing getdamage and lca")
+
+    # damage patterns will be calculated for each chr/scaffold contig.
+    elif runmode == "local":
+        return 1
+
+    # one global estimate
+    elif runmode == "global":
+        return 0
+
+    raise AssertionError(f"Got wrong runmode. Got: {runmode}")
+
+
+def get_damage_command(config):
+    "'Direct' damage, no LCA"
+
+    outname = config["path_tmp"] / config["sample"]
+    runmode = get_runmode(config)
+
+    command = (
+        f"{config['metaDMG-lca']} getdamage "
+        f"--minlength 10 "
+        f"--printlength {config['max_position']} "
+        f"--threads 8 "
+        f"--runmode {runmode} "
+        f"--outname {outname} "
+        f"{config['bam']} "
+    )
+    return command[:-1]
+
+
+def get_damage_ugly_command(config):
+    bdamage = config["path_tmp"] / f"{config['sample']}.bdamage.gz"
+    command = f"{config['metaDMG-lca']} print_ugly " f"{bdamage} "
+    return command[:-1]
+
+
+#%%
+
+
 def move_files(config):
 
     sample = config["sample"]
+    path_tmp = config["path_tmp"]
+
+    mismatch = path_tmp / f"{sample}.bdamage.gz.uglyprint.mismatch.txt.gz"
+    stat = path_tmp / f"{sample}.bdamage.gz.uglyprint.stat.txt.gz"
 
     d_move_source_target = {
-        f"{sample}.bdamage.gz.uglyprint.mismatch.txt.gz": config["path_mismatches_txt"],
-        f"{sample}.bdamage.gz.uglyprint.stat.txt.gz": config["path_mismatches_stat"],
-        f"{sample}.lca.gz": config["path_lca"],
-        f"{sample}.log": config["path_lca_log"],
+        mismatch: config["path_mismatches_txt"],
+        stat: config["path_mismatches_stat"],
+        path_tmp / f"{sample}.lca.gz": config["path_lca"],
+        path_tmp / f"{sample}.log": config["path_lca_log"],
     }
     for source_path, target_path in d_move_source_target.items():
         logger.debug(f"Moving {source_path} to {target_path}.")
@@ -104,40 +156,38 @@ def move_files(config):
         shutil.move(source_path, target_path)
 
 
-def delete_files(config):
+def move_files_non_lca(config):
 
     sample = config["sample"]
+    path_tmp = config["path_tmp"]
 
-    bam = Path(config["bam"]).stem  # .name
+    mismatch = path_tmp / f"{sample}.bdamage.gz.uglyprint.mismatch.txt.gz"
+    stat = path_tmp / f"{sample}.stat"
 
-    paths_to_remove = [
-        f"{sample}.lca.stat",
-        f"{sample}.bdamage.gz",
-        *list(Path(".").glob(f"*{bam}*.bin")),
-    ]
-    for path in paths_to_remove:
-        logger.debug(f"Removing {path}.")
-        if not Path(path).is_file():
-            raise metadamageError(f"{path} does not exist.")
-        Path(path).unlink()
+    d_move_source_target = {
+        mismatch: config["path_mismatches_txt"],
+        stat: config["path_mismatches_stat"],
+    }
+    for source_path, target_path in d_move_source_target.items():
+        logger.debug(f"Moving {source_path} to {target_path}.")
+        if not Path(source_path).is_file():
+            raise metadamageError(f"{source_path} does not exist.")
+        Path(target_path).parent.mkdir(parents=True, exist_ok=True)
+        shutil.move(source_path, target_path)
 
 
-def delete_all_sample_files(config):
-    sample = config["sample"]
+#%%
 
-    bam = Path(config["bam"]).stem  # .name
 
-    paths_to_remove = [
-        f"{sample}.lca",
-        f"{sample}.lca.stat",
-        f"{sample}.log",
-        f"{sample}.bdamage.gz",
-        *list(Path(".").glob(f"*{bam}*.bin")),
-    ]
-    for path in paths_to_remove:
-        if Path(path).is_file():
-            logger.debug(f"Removing {path}.")
-            Path(path).unlink()
+def create_tmp_dir(config):
+    Path(config["path_tmp"]).mkdir(parents=True, exist_ok=True)
+
+
+def delete_tmp_dir(config):
+    path_tmp = Path(config["path_tmp"])
+    for file in path_tmp.glob("*"):
+        file.unlink()
+    path_tmp.rmdir()
 
 
 #%%
@@ -220,6 +270,8 @@ def run_LCA(config, forced=False):
         command_LCA = get_LCA_command(config)
         command_LCA_mismatches = get_LCA_mismatches_command(config)
 
+        create_tmp_dir(config)
+
         logger.debug(command_LCA)
         run_command_helper(config, command_LCA)
 
@@ -227,7 +279,7 @@ def run_LCA(config, forced=False):
         run_command_helper(config, command_LCA_mismatches)
 
         move_files(config)
-        delete_files(config)
+        delete_tmp_dir(config)
 
     else:
         logger.info(f"LCA already been run before.")
@@ -236,6 +288,49 @@ def run_LCA(config, forced=False):
 #%%
 
 
+def run_damage_no_lca(config, forced=False):
+
+    logger.info(f"Getting damage. NOTE: NO LCA.")
+
+    targets = [
+        config["path_mismatches_txt"],
+        config["path_mismatches_stat"],
+    ]
+
+    if do_run(targets, forced=forced):
+        logger.info(f"Getting damage. NOTE: NO LCA.")
+
+        command_damage = get_damage_command(config)
+        command_damage_ugly = get_damage_ugly_command(config)
+
+        create_tmp_dir(config)
+
+        logger.debug(command_damage)
+        run_command_helper(config, command_damage)
+
+        logger.debug(command_damage_ugly)
+        run_command_helper(config, command_damage_ugly)
+
+        move_files_non_lca(config)
+        delete_tmp_dir(config)
+
+    else:
+        logger.info(f"LCA already been run before.")
+
+
+#%%
+
+
+def run_thorfinn(config, forced=False):
+    if config["damage_mode"] == "lca":
+        run_LCA(config, forced=forced)
+    else:
+        run_damage_no_lca(config, forced=forced)
+
+
+#%%
+
+
 def get_df_mismatches(config, forced=False):
 
     logger.info(f"Getting df_mismatches")
@@ -319,7 +414,7 @@ def get_df_results(config, df_mismatches, df_fit_results, forced=False):
 
     # Compute the results:
     logger.info(f"Computing df_results.")
-    df_results = results.merge(df_mismatches, df_fit_results)
+    df_results = results.merge(config, df_mismatches, df_fit_results)
     Path(target).parent.mkdir(parents=True, exist_ok=True)
     df_results.to_parquet(target)
 
@@ -348,7 +443,7 @@ def run_single_config(config):
     forced = config["forced"]
 
     try:
-        run_LCA(config, forced=forced)
+        run_thorfinn(config, forced=forced)
     except metadamageError:
         logger.exception(
             f"{config['sample']} | metadamageError with run_LCA. "
@@ -357,7 +452,7 @@ def run_single_config(config):
         return None
     except KeyboardInterrupt:
         logger.info("Got KeyboardInterrupt. Cleaning up.")
-        delete_all_sample_files(config)
+        delete_tmp_dir(config)
         raise KeyboardInterrupt
 
     try:
